{% if not nav_item.children %}
  {% if nav_item.active %}
  <li class="active">
      {{ nav_item.title }}
  </li>
  {% else %}
  <li>
      <a href="{{ nav_item.url|url }}">{{ nav_item.title }}</a>
  </li>
  {% endif %}
{% else %}
  <li class="has-children">
    <a class="nav-child-title" onclick="toggleNavChild()">{{ nav_item.title }}</a>
    <ul class="nav-child">
      {% for nav_item in nav_item.children %}
        {% include "nav.html" %}
      {% endfor %}
    </ul>
  </li>
{% endif %}
