{% extends "base.html" %}

{% block extrahead %}
  <script>var base_url = '{{ base_url }}';</script>
{% endblock %}

{% block content %}

  <h1 id="search">Search results</h1>

  <form id="content_search" action="search.html">
    <span role="status" aria-live="polite" class="ui-helper-hidden-accessible"></span>
    <input name="q" id="mkdocs-search-query" type="text" class="search_input search-query ui-autocomplete-input" placeholder="Find in documentation" autocomplete="off">
  </form>

  <div id="mkdocs-search-results"></div>

{% endblock %}
