<!--
  Customize contents with custom_dir and style with extra_css https://www.mkdocs.org/user-guide/customizing-your-theme/
-->
<footer>
  <div class="container">
    <div class="row">
      <div class="six columns">
        &nbsp;
      </div>
      <div class="six columns">
        <div class="info">
          <p><span id="last-update-date">{{build_date_utc}}</span></p>
          <p class="copyright">&copy;<span id="copyright-date"></span> Organization name</p>
        </div>
      </div>
    </div>
  </div>
</footer>