{% extends "base.html" %}

{% block content %}

  <h3 id="page404">Ops... Page not found!</h3>

  <p class="page404-message">
    I'm sorry, but I can't find the page you are looking for.
  </p>

{% endblock %}
