/* FOOTER */

footer {
  padding-top: 8vh;
  padding-bottom: 8vh;
  background-color: var(--text);
  background-color: var(--darker);
}

footer .info {
  margin-top: 5vh;
  margin-left: 7rem;
}

@media (min-width: 750px) {
  footer .info {
    margin-left: 0;
  }
}

footer .info p {
  color: var(--white);
  opacity: 0.9;
  margin-bottom: 0;
  font-size: 1.6rem;
}

footer .info p.copyright {
  opacity: 0.6;
  font-size: 1.4rem;
  margin-top: 0.5rem;
}
