/* GENERAL */
:root {
  --text: #17324D;
  --main: #0066CC;
  --dark: #0059B3;
  --darker: #004080;
  --light: #408AD5;
  --ultra-light: #dbe7ed;
  --accent: #39beba;
  --accent-light: #3DCCC7;
  --accent-dark: #32A6A2;
  --secondary: #CED1D9;
  --secondary-dark: #919399;
  --secondary-darker: #555659;
  --secondary-light: #E6E9F2;
  --secondary-ultra-light: #F2F5FF;
  --white: #ffffff;
  --red: #F83E5A;
  --red-dark: #DE3750;
  --font-family: 'Titillium', sans-serif;
}

body {
  font-weight: 400;
  font-family: var(--font-family);
  color: var(--text);
  font-size: 1.8em;
  font-style: normal;
}

body.show-modal-search,
body.show-modal-img {
  overflow: hidden;
}

strong {
  font-weight: 700;
  font-style: normal;
}

@media print {
  strong {
    font-weight: 700;
    font-style: normal;
  }
}

em {
  font-style: italic;
  font-size: 101%;
}

img {
  width: 100%;
  height: auto;
}

h1, h2, h3, h4, h5, h6 {
  margin-top: 0;
  margin-bottom: 2.1rem;
  font-weight: 400; }
h1 { font-size: 4.2rem; line-height: 1.2;  letter-spacing: normal; }
h2 { font-size: 3.4rem; line-height: 1.2; letter-spacing: normal; }
h3 { font-size: 2.4rem; line-height: 1.2;  letter-spacing: normal; }
h4 { font-size: 2.1rem; line-height: 1.2; letter-spacing: normal; }
h5 { font-size: 1.8rem; line-height: 1.2;  letter-spacing: normal; }
h6 { font-size: 1.5rem; line-height: 1.2;  letter-spacing: normal; }

/* Larger than phablet */
@media (min-width: 550px) {
  h1 { font-size: 5.5rem; }
  h2 { font-size: 4.2rem; }
  h3 { font-size: 3.4rem; }
  h4 { font-size: 2.9rem; }
  h5 { font-size: 2.4rem; }
  h6 { font-size: 1.8rem; }
}

a {
  color: var(--main);
  text-decoration: none;
  -webkit-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
a:hover {
  color: var(--main);
  text-decoration: underline;
}

a.underlined {
  color: var(--main);
  text-decoration: underline;
}
a.underlined:hover {
  color: #004D99;
}

a.headerlink {
  color: #E6E9F2;
  font-size: 90%;
  text-decoration: none;
  margin-left: 0.5rem;
}
a.headerlink:hover {
  color: var(--main);
  text-decoration: none;
}

pre, blockquote, dl, figure, table, p, ul, ol, form {
  margin-bottom: 2.1rem;
}

figcaption {
  margin-left: 2%;
  margin-right: 2%;
  margin-top: -2.4rem;
  margin-bottom: 3.9rem;
  padding-left: 0.3rem;
  padding-right: 0.3rem;
  font-size: 1.5rem;
  opacity: 0.6;
}

.button,
button,
input[type="submit"],
input[type="reset"],
input[type="button"] {
  display: inline-block;
  height: auto;
  padding: 0 3.4rem;
  color: var(--white);
  text-align: center;
  font-size: 1.5rem;
  font-weight: 400;
  line-height: 3.2rem;
  letter-spacing: 0;
  text-transform: capitalize;
  text-decoration: none;
  white-space: nowrap;
  border-radius: 4px;
  background-color: #0073E6;
  border: 0.2rem solid #0073E6;
  border-radius: 2.4rem;
  cursor: pointer;
  box-sizing: border-box;
  -webkit-transition: all 0.3s ease;
  transition: all 0.3s ease;
}

.button[disabled],
button[disabled],
input[disabled] {
  opacity: 0.5;
}

.button:hover,
button:hover,
input[type="submit"]:hover,
input[type="reset"]:hover,
input[type="button"]:hover,
.button:focus,
button:focus,
input[type="submit"]:focus,
input[type="reset"]:focus,
input[type="button"]:focus {
  color: var(--white);
  background-color: var(--dark);
  border-color: var(--dark);
  outline: 0;
}

.button.button-secondary,
button.button-secondary,
input[type="submit"].button-secondary,
input[type="reset"].button-secondary,
input[type="button"].button-secondary {
  color: var(--main);
  background-color: transparent;
  border-color: var(--main);
}

.button.button-secondary:hover,
button.button-secondary:hover,
input[type="submit"].button-secondary:hover,
input[type="reset"].button-secondary:hover,
input[type="button"].button-secondary:hover,
.button.button-secondary:focus,
button.button-secondary:focus,
input[type="submit"].button-secondary:focus,
input[type="reset"].button-secondary:focus,
input[type="button"].button-secondary:focus {
  color: var(--dark);
  background-color: transparent;
  border-color: var(--dark);
}

.button.button-tertiary,
button.button-tertiary,
input[type="submit"].button-tertiary,
input[type="reset"].button-tertiary,
input[type="button"].button-tertiary {
  color: var(--white);
  background-color: var(--secondary);
  border-color: var(--secondary);
}

.button.button-tertiary:hover,
button.button-tertiary:hover,
input[type="submit"].button-tertiary:hover,
input[type="reset"].button-tertiary:hover,
input[type="button"].button-tertiary:hover,
.button.button-tertiary:focus,
button.button-tertiary:focus,
input[type="submit"].button-tertiary:focus,
input[type="reset"].button-tertiary:focus,
input[type="button"].button-tertiary:focus {
  color: var(--white);
  background-color: var(--text);
  border-color: var(--text);
}

.button.button-accent,
button.button-accent,
input[type="submit"].button-accent,
input[type="reset"].button-accent,
input[type="button"].button-accent {
  color: var(--white);
  background-color: var(--accent-light);
  border-color: var(--accent-light);
}

.button.button-accent:hover,
button.button-accent:hover,
input[type="submit"].button-accent:hover,
input[type="reset"].button-accent:hover,
input[type="button"].button-accent:hover,
.button.button-accent:focus,
button.button-accent:focus,
input[type="submit"].button-accent:focus,
input[type="reset"].button-accent:focus,
input[type="button"].button-accent:focus {
  color: var(--white);
  background-color: var(--accent);
  border-color: var(--accent);
}

.button.button-accent-secondary,
button.button-accent-secondary,
input[type="submit"].button-accent-secondary,
input[type="reset"].button-accent-secondary,
input[type="button"].button-accent-secondary {
  color: var(--accent-light);
  background-color: transparent;
  border-color: var(--accent-light);
}

.button.button-accent-secondary:hover,
button.button-accent-secondary:hover,
input[type="submit"].button-accent-secondary:hover,
input[type="reset"].button-accent-secondary:hover,
input[type="button"].button-accent-secondary:hover,
.button.button-accent-secondary:focus,
button.button-accent-secondary:focus,
input[type="submit"].button-accent-secondary:focus,
input[type="reset"].button-accent-secondary:focus,
input[type="button"].button-accent-secondary:focus {
  color: var(--accent);
  background-color: transparent;
  border-color: var(--accent);
}

input[type="email"],
input[type="number"],
input[type="search"],
input[type="text"],
input[type="tel"],
input[type="url"],
input[type="password"],
textarea,
select {
  height: auto;
  padding: 0 1.3rem;
  font-size: 1.8rem;
  font-weight: 600;
  line-height: 3.4rem;
  background-color: transparent;
  border: 1px solid #BCC0CC;
  font-weight: 400;
  font-size: 1.5rem;
  border-radius: 2.4rem;
}

input[type="email"]:focus,
input[type="number"]:focus,
input[type="search"]:focus,
input[type="text"]:focus,
input[type="tel"]:focus,
input[type="url"]:focus,
input[type="password"]:focus,
textarea:focus,
select:focus {
  border: 1px solid var(--main);
  outline: 0;
}

code, kbd, pre, samp {
  font-family: "Roboto Mono", monospace;
  font-weight: 400;
}

code {
  background-color: #FCFCFF;
  border-color: #E6E9F2;
  overflow-x: auto;
}

pre > code {
  padding: 2.1rem;
}

.codehilite {
  background-color: transparent;
}

.container {
  max-width: 1460px;
  width: 96%;
}

@media (min-width: 400px) {
  .container {
    width: 96%;
  }
}

@media (min-width: 550px) {
  .container {
    width: 90%;
  }
}

.overlay-utility {
  content: "";
  position: fixed;
  background-color: rgba(255, 255, 255, 0.9);
  right: 0;
  top: 0;
  bottom: 0;
  left: 0;
  z-index: -1;
  visibility: hidden;
  display: none;
  opacity: 0;
  -webkit-transition: opacity 0.3s ease;
  transition: opacity 0.3s ease;
}

.show-docs-nav .overlay-utility  {
  opacity: 1;
  visibility: visible;
  display: block;
  z-index: 9997;
}

.highlight {
  color: var(--accent-light);
}

.video-container {
  overflow: hidden;
  padding-bottom: 56.25%;
  width: 100%;
  line-height: 0;
  position: relative;
}

.video-container iframe[style] {
  height: calc(100% + 2px) !important;
  left: -1px !important;
  position: absolute !important;
  top: -1px !important;
  width: calc(100% + 2px) !important;
  border: 0 !important;
  outline: 0px;
}

video {
  width: 100%;
  height: auto;
  margin-top: 3.4rem;
  -webkit-box-shadow: 0px 0px 34px 0px rgba(0,61,92,0.1);
  box-shadow: 0px 0px 34px 0px rgba(0,61,92,0.1);
}

/* FONTS */
@font-face {
  font-family: "Titillium";
  src: url("../fonts/Titillium_Web/TitilliumWeb-Regular.woff2") format("woff2"),
       url("../fonts/Titillium_Web/TitilliumWeb-Regular.woff") format("woff");
  font-weight: 400;
  font-style: normal;
}

@font-face {
  font-family: "Titillium";
  src: url("../fonts/Titillium_Web/TitilliumWeb-Regular-Italic.woff2") format("woff2"),
       url("../fonts/Titillium_Web/TitilliumWeb-Regular-Italic.woff") format("woff");
  font-weight: 400;
  font-style: italic;
}

@font-face {
  font-family: "Titillium";
  src: url("../fonts/Titillium_Web/TitilliumWeb-Bold.woff2") format("woff2"),
       url("../fonts/Titillium_Web/TitilliumWeb-Bold.woff") format("woff");
  font-weight: 700;
  font-style: normal;
}

@font-face {
  font-family: "Titillium";
  src: url("../fonts/Titillium_Web/TitilliumWeb-Bold-Italic.woff2") format("woff2"),
       url("../fonts/Titillium_Web/TitilliumWeb-Bold-Italic.woff") format("woff");
  font-weight: 700;
  font-style: italic;
}

@font-face {
  font-family: "Titillium";
  src: url("../fonts/Titillium_Web/TitilliumWeb-SemiBold.woff2") format("woff2"),
       url("../fonts/Titillium_Web/TitilliumWeb-SemiBold.woff") format("woff");
  font-weight: 600;
  font-style: normal;
}

@font-face {
  font-family: "Titillium";
  src: url("../fonts/Titillium_Web/TitilliumWeb-SemiBold-Italic.woff2") format("woff2"),
       url("../fonts/Titillium_Web/TitilliumWeb-SemiBold-Italic.woff") format("woff");
  font-weight: 600;
  font-style: italic;
}

@font-face {
  font-family: "Roboto Mono";
  src: url("../fonts/Roboto_Mono/RobotoMono-Regular.woff2") format("woff2"),
       url("../fonts/Roboto_Mono/RobotoMono-Regular.woff") format("woff");
  font-weight: 400;
}

@font-face {
  font-family: "Roboto Mono";
  src: url("../fonts/Roboto_Mono/RobotoMono-Bold.woff2") format("woff2"),
       url("../fonts/Roboto_Mono/RobotoMono-Bold.woff") format("woff");
  font-weight: 700;
}

/* HEADER */

header {
  padding: 0.6rem 1.5rem;
  background-color: var(--main);
}

header .top-bar {
  display: -webkit-box;      /* OLD - iOS 6-, Safari 3.1-6 */
  display: -moz-box;         /* OLD - Firefox 19- (buggy but mostly works) */
  display: -ms-flexbox;      /* TWEENER - IE 10 */
  display: -webkit-flex;     /* NEW - Chrome */
  display: flex;
  -webkit-align-items: center;
  -ms-align-items: center;
  align-items: center;
  -webkit-align-content: center;
  -ms-align-content: center;
  align-content: center;
  -webkit-justify-content: space-between;
  -ms-justify-content: space-between;
  justify-content: space-between;
}

header .platform-heading {
  display: -webkit-box;      /* OLD - iOS 6-, Safari 3.1-6 */
  display: -moz-box;         /* OLD - Firefox 19- (buggy but mostly works) */
  display: -ms-flexbox;      /* TWEENER - IE 10 */
  display: -webkit-flex;     /* NEW - Chrome */
  display: flex;
  -webkit-align-items: center;
  -ms-align-items: center;
  align-items: center;
  -webkit-align-content: center;
  -ms-align-content: center;
  align-content: center;
  -webkit-justify-content: flex-start;
  -ms-justify-content: flex-start;
  justify-content: flex-start;
}

header .platform-logo {
  margin-right: 1.3rem;
  line-height: 0;
}

header .platform-logo img {
  height: 3.6rem;
  width: auto;
}

header h1 {
  color: var(--white);
  font-size: 1.6rem;
  font-weight: 400;
  letter-spacing: .05rem;
  margin-bottom: 0;
  line-height: 1.2;
}

header h2 {
  color: var(--white);
  opacity: 0.7;
  font-size: 1.4rem;
  font-weight: 400;
  letter-spacing: .05rem;
  margin-bottom: 0;
  line-height: 1;
}

.tool {
  display: -webkit-box;      /* OLD - iOS 6-, Safari 3.1-6 */
  display: -moz-box;         /* OLD - Firefox 19- (buggy but mostly works) */
  display: -ms-flexbox;      /* TWEENER - IE 10 */
  display: -webkit-flex;     /* NEW - Chrome */
  display: flex;
  -webkit-align-items: center;
  -ms-align-items: center;
  align-items: center;
  -webkit-align-content: center;
  -ms-align-content: center;
  align-content: center;
  -webkit-justify-content: flex-end;
  -ms-justify-content: flex-end;
  justify-content: flex-end;
}

.tool-label {
  color: var(--white);
  margin-right: 0.5rem;
  font-size: 1.6rem;
}

.tool-trigger {
  cursor: pointer;
  width: 2.9rem;
  height: 2.9rem;
  border-radius: 50%;
  background-color: rgba(255,255,255,0.2);
  position: relative;
  -webkit-transition: all 0.3s ease;
  transition: all 0.3s ease;
}

.tool-trigger:hover {
  background-color: rgba(255,255,255,0.3);
  -webkit-transform: scale(1.04);
  transform: scale(1.04);
}

.tool-trigger img {
  position: absolute;
  width: 1.8rem;
  height: auto;
  top: 50%;
  left: 50%;
  margin-left: -0.9rem;
  margin-top: -0.9rem;
}

.tool-docs-navigation {
  position: absolute;
  left: 0;
  right: 0;
  top: 4.8rem;
  padding-top: 0.5rem;
  padding-bottom: 0.5rem;
  -webkit-justify-content: flex-start;
  justify-content: flex-start;
  z-index: 999;
  background-color: var(--secondary-light);
}

@media (min-width: 1300px) {
  .tool-docs-navigation {
    display: none;
  }
}

.tool-docs-navigation .tool-trigger {
  background-color: transparent;
  margin-left: 0.8rem;
}

.tool-docs-navigation .tool-label {
  color: var(--main);
}

/* SEARCH */

.search form {
  margin-bottom: 0;
}

.search input {
  margin-bottom: 1.1rem;
  display: block;
  width: 100%;
  border-color: #BCC0CC;
}

.search h4 {
  margin-top: 1.3rem;
  margin-bottom: 2.9rem;
  padding-left: 0.2rem;
  padding-right: 0.2rem;
}

#content_search input[type="text"] {
  width: 100%;
  padding-top: 0.3rem;
  padding-bottom: 0.3rem;
}

.search-has-no-results #mkdocs-search-results p {
  display: none;
}

/* MAIN */

.main {
  padding-top: 8vh;
  padding-bottom: 8vh;
}

.main .two.columns.columns-docs-navigation {
  position: fixed;
  width: 85%;
  background-color: var(--darker);
  left: 0;
  top: 0;
  bottom: 0;
  overflow-y: auto;
  z-index: 9998;
  -webkit-transform: translateX(-100%);
  transform: translateX(-100%);
  -webkit-transition: transform 0.3s ease;
  transition: transform 0.3s ease;
}

.show-docs-nav .main .two.columns.columns-docs-navigation {
  -webkit-transform: translateX(0);
  transform: translateX(0);
}

@media (min-width: 550px) {
  .main .two.columns.columns-docs-navigation {
    width: 70%;
  }
}

@media (min-width: 750px) {
  .main .columns {
    margin-left: 2%;
  }
  .main .column:first-child,
  .main .columns:first-child {
    margin-left: 0;
  }
  .main .two.columns {
    width: 20%;
  }
  .main .two.columns.columns-docs-navigation {
    width: 50%;
  }
  .main .eight.columns {
    width: 78%;
  }
  .main .eight.columns.columns-contents {
    margin-left: 0;
  }
}

@media (min-width: 1300px) {
  .main .two.columns {
    width: 16%;
  }
  .main .two.columns.columns-docs-navigation {
    position: relative;
    width: 16%;
    background-color: transparent;
    overflow-x: visible;
    overflow-y: visible;
    z-index: 1;
    -webkit-transform: translateX(0);
    transform: translateX(0);
  }
  .main .two.columns.columns-docs-navigation::before {
    display: none;
  }
  .main .eight.columns {
    width: 64%;
  }
  .main .eight.columns.columns-contents {
    margin-left: 2%;
  }
}

.docs-navigation {
  padding: 2.1rem;
  padding-top: 2.8rem;
}

@media (min-width: 750px) {
  .docs-navigation {
    padding: 4.2rem;
    padding-top: 8vh;
  }
}

@media (min-width: 1300px) {
  .docs-navigation {
    padding: 0;
  }
}

.docs-navigation .close {
  position: fixed;
  top: 1.1rem;
  right: 1.1rem;
  z-index: 9999;
  cursor: pointer;
  width: 2.9rem;
  height: 2.9rem;
  border-radius: 50%;
  background-color: rgba(255,255,255,0.2);
  -webkit-transition: all 0.3s ease 0.3s;
  transition: all 0.3s ease 0.3s;
  -webkit-transform: scale(0);
  transform: scale(0);
  opacity: 0;
}

.show-docs-nav .docs-navigation .close {
  -webkit-transform: scale(1);
  transform: scale(1);
  opacity: 1;
}

@media (min-width: 1300px) {
  .docs-navigation .close {
    display: none;
  }
}

.docs-navigation .close:hover {
  background-color: rgba(255,255,255,0.3);
  -webkit-transform: scale(1.04);
  transform: scale(1.04);
}

.docs-navigation .close img {
  position: absolute;
  width: 1.8rem;
  height: auto;
  top: 50%;
  left: 50%;
  margin-left: -0.9rem;
  margin-top: -0.9rem;
}

@media (min-width: 750px) {
  .columns-table-of-contents.sticky {
    position: -webkit-sticky;
    position: sticky;
    top: 8vh;
    -webkit-transition: all 0.3s ease;
    transition: all 0.3s ease;
  }
  .columns-table-of-contents.hide {
    top: 0;
    -webkit-transform: translateY(-110%);
    transform: translateY(-110%);
  }
}

.search-page .table-of-contents {
  display: none;
}

.docs-navigation h6,
.table-of-contents h6 {
  font-weight: 700;
  margin-bottom: 0.5rem;
  font-size: 1.6rem;
  line-height: 1.5;
}

.docs-navigation h6 {
  font-size: 2.9rem;
  color: rgba(255,255,255,0.5);
  font-weight: 400;
  margin-bottom: 2.1rem;
}

@media (min-width: 1300px) {
  .docs-navigation h6 {
    font-weight: 700;
    margin-bottom: 0.5rem;
    font-size: 1.6rem;
    color: var(--text);
    display: block;
  }
}

.docs-navigation ul,
.table-of-contents ul {
  list-style: none;
  margin-bottom: 0;
  font-size: 1.6rem;
}

.docs-navigation ul {
  font-size: 1.8rem;
}

@media (min-width: 1300px) {
  .docs-navigation ul {
    font-size: 1.6rem;
  }
}

.docs-navigation ul li,
.table-of-contents ul li {
  margin-bottom: 0.5rem;
  line-height: 1.4;
}

.docs-navigation ul ul,
.table-of-contents ul ul {
  margin-top: 0.5rem;
  margin-left: 1.3rem;
}

.docs-navigation ul ul {
  font-size: 1.6rem;
}

@media (min-width: 1300px) {
  .docs-navigation ul ul {
    font-size: 1.5rem;
  }
}

.docs-navigation li.active {
  color: var(--accent);
}

.docs-navigation .nav-child-title {
  cursor: pointer;
  position: relative;
  display: block;
  text-decoration: none;
}

.docs-navigation .nav-child-title:hover {
  opacity: 0.9;
}

@media (min-width: 1300px) {
  .docs-navigation .nav-child-title:hover {
    color: var(--darker);
    opacity: 1;
  }
}

.docs-navigation .nav-child-title::before {
  content: "";
  position: absolute;
  left: -2.1rem;
  top: 0.4rem;
  width: 1.8rem;
  height: 1.8rem;
  opacity: 0.8;
  background-image: url(../img/iconic/chevron-down-circle-white.svg);
  background-size: contain;
  background-repeat: no-repeat;
  background-position: left center;
}

@media (min-width: 1300px) {
  .docs-navigation .nav-child-title::before {
    top: 0.3rem;
    opacity: 0.4;
    background-image: url(../img/iconic/chevron-down-circle.svg);
  }
}

.docs-navigation ul ul .nav-child-title::before {
  top: 0.4rem;
}

@media (min-width: 1300px) {
  .docs-navigation ul ul .nav-child-title::before {
    top: 0.3rem;
  }
}

.docs-navigation .nav-child {
  height: 0;
  margin-top: 0;
  overflow: hidden;
  -webkit-transition: all 0.3s ease;
  transition: all 0.3s ease;
}

.docs-navigation ul li.show-nav-child > ul.nav-child {
  margin-top: 0.5rem;
  height: auto;
  overflow: visible;
}

.docs-navigation ul li.show-nav-child > .nav-child-title::before {
  background-image: url(../img/iconic/chevron-up-circle-white.svg);
}

@media (min-width: 1300px) {
  .docs-navigation ul li.show-nav-child > .nav-child-title::before {
    background-image: url(../img/iconic/chevron-up-circle.svg);
  }
}

.docs-navigation li a {
  color: var(--white);
}

@media (min-width: 1300px) {
  .docs-navigation li a {
    color: var(--main);
  }
}

.docs-navigation .search {
  display: -webkit-box;      /* OLD - iOS 6-, Safari 3.1-6 */
  display: -moz-box;         /* OLD - Firefox 19- (buggy but mostly works) */
  display: -ms-flexbox;      /* TWEENER - IE 10 */
  display: -webkit-flex;     /* NEW - Chrome */
  display: flex;
  -webkit-align-items: center;
  -ms-align-items: center;
  align-items: center;
  -webkit-align-content: center;
  -ms-align-content: center;
  align-content: center;
  -webkit-justify-content: flex-start;
  -ms-justify-content: flex-start;
  justify-content: flex-start;
  width: 80%;
  margin-bottom: 5.5rem;
}

@media (min-width: 1300px) {
  .docs-navigation .search {
    display: none;
  }
}

.docs-navigation .search form {
  display: block;
  width: 100%;
}

.docs-navigation .search input[type="search"] {
  background-color: var(--white);
  width: 100%;
  padding-right: 3.9rem;
  display: block;
  background-image: url(../img/iconic/search.svg);
  background-position: right center;
  background-repeat: no-repeat;
  background-size: 3.4rem auto;
  margin-bottom: 0;
}

.docs-navigation .search button {
  height: 4.4rem;
  display: inline-block;
  margin-left: 0.3rem;
}

.docs-navigation .search button[disabled] {
  opacity: 0.8;
}

.docs-navigation .search button img {
  width: 2.4rem;
  height: auto;
  -webkit-transform: translateY(0.5rem);
  transform: translateY(0.5rem);
}

.contents img {
  display: block;
  margin: 0 auto;
  margin-top: 3.9rem;
  margin-bottom: 3.9rem;
  width: auto;
  max-width: 96%;
  -webkit-box-shadow: 0px 0px 34px 0px rgba(0,38,77,0.1);
  box-shadow: 0px 0px 34px 0px rgba(0,38,77,0.1);
  cursor: pointer;
  position: relative;
}

.contents blockquote img {
  margin-top: 0;
  margin-bottom: 0;
}

.contents img[alt=inline-icon] {
  display: inline;
  vertical-align: middle;
  margin: 0;
  margin-top: 0;
  margin-bottom: 0;
  -webkit-box-shadow: none;
  box-shadow: none;
  cursor: default;
}

.contents img.uml,
.contents img[alt=diagram],
.contents img.mmd,
.modal img.uml,
.modal img[alt=diagram],
.modal img.mmd {
  -webkit-box-shadow: none;
  box-shadow: none;
  width: 100%;
  max-width: 100%;
  padding-top: 1.1rem;
  padding-bottom: 1.1rem;
}

.modal img.uml,
.modal img.mmd {
  display: block;
  background-color: var(--white);
}

.search-page .contents article {
  padding-left: 0.2rem;
  padding-right: 0.2rem;
}

.contents h1, .contents h2, .contents h3, .contents h4, .contents h5, .contents h6 {
  -webkit-transition: all 0.3s ease;
  transition: all 0.3s ease;
}

.search-page .contents h1 {
  padding-left: 0.2rem;
  padding-right: 0.2rem;
}

.contents h2 {
  padding-top: 2.1rem;
}

.contents h3 {
  padding-top: 1.3rem;
}

.contents article h3 {
  margin-bottom: 0.3rem;
}

.contents article h3 a {
  text-decoration: none;
}

.contents article h3 a:hover {
  color: var(--accent);
}

.contents h4 {
  padding-top: 0.8rem;
}

.contents p {
  position: relative;
}

.search-page .contents div#mkdocs-search-results p {
  padding-left: 0.4rem;
  padding-right: 0.4rem;
  opacity: 0.5;
}

.search-page .contents div#mkdocs-search-results article p {
  padding-left: 0;
  padding-right: 0;
  opacity: 1;
}

.contents p.location {
  font-size: 1.3rem;
  opacity: 0.5;
  line-height: 1.4;
}

.search-page .contents div#mkdocs-search-results article p.location {
  opacity: 0.5;
}

.contents ul, .contents ol {
  padding-left: 2.1rem;
}

.contents ol {
  list-style: decimal outside;
}

.contents ul{
  list-style: disc outside;
}

.contents ul ul {
  padding-left: 0;
  list-style: circle outside;
}

.contents ul ul, .contents ul ol, .contents ol ol, .contents ol ul {
  font-size: 100%;
}

.contents ul ul ul {
  list-style: none;
  padding-left: 0;
  margin-left: 1.3rem;
}

.contents ul ul ul li {
  position: relative;
  padding-left: 1.3rem;
}

.contents ul ul ul li::before {
  content: '-';
  position: absolute;
  left: 0;
}

.contents table {
  display: inline-block;
  width: auto;
  max-width: 100%;
  overflow-x: auto;
  position: relative;
  z-index: 1;
  font-size: 1.5rem;
  background-color: #FCFCFF;
  border-radius: 0.8rem;
}

.contents blockquote {
  position: relative;
  margin: 0;
  margin-bottom: 2.9rem;
  margin-top: 2.9rem;
  padding: 3.4rem 2.1rem;
  background-color: var(--secondary-light);
  border-radius: 0.8rem;
}

.contents blockquote::before {
  content: "";
  position: absolute;
  top: 0.2rem;
  right: 0.2rem;
  display: block;
  width: 2.9rem;
  height: 2.9rem;
  background-image: url(../img/iconic/annotation-warning-blu.svg);
  background-position: center center;
  background-size: contain;
  background-repeat: no-repeat;
}

.contents blockquote p:last-child,
.contents blockquote ul:last-child,
.contents blockquote ol:last-child {
  margin-bottom: 0;
}

.page-404 .table-of-contents {
  display: none;
}

.page-404 .contents {
  padding-left: 4.2rem;
}

.page404-message {
  margin-bottom: 21vh;
  padding-left: 0.2rem;
  font-size: 1.8rem;
  margin-top: 8vh;
}

/* MODAL */

.modal {
  content: "";
  position: fixed;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  background-color: rgba(255, 255, 255, 0.9);
  z-index: -1;
  visibility: hidden;
  opacity: 0;
  display: -webkit-box;      /* OLD - iOS 6-, Safari 3.1-6 */
  display: -moz-box;         /* OLD - Firefox 19- (buggy but mostly works) */
  display: -ms-flexbox;      /* TWEENER - IE 10 */
  display: -webkit-flex;     /* NEW - Chrome */
  display: flex;
  -webkit-align-items: center;
  -ms-align-items: center;
  align-items: center;
  -webkit-align-content: center;
  -ms-align-content: center;
  align-content: center;
  -webkit-justify-content: center;
  -ms-justify-content: center;
  justify-content: center;
}

.modal-img {
  -webkit-align-items: flex-start;
  -ms-align-items: flex-start;
  align-items: flex-start;
  overflow-y: auto;
  background-color: rgba(230, 233, 242, 0.9);
}

.show-modal-search .modal-search,
.show-modal-img .modal-img {
  z-index: 9997;
  visibility: visible;
  opacity: 1;
  -webkit-transition: opacity 0.3s ease 0.1s;
  transition: opacity 0.3s ease 0.1s;
}

.modal-inner-box {
  position: relative;
  width: 90%;
  max-width: 42rem;
  z-index: 9998;
  background-color: #fff;
  -webkit-box-shadow: 0px 0px 34px 0px rgba(0,0,0,0.08);
  box-shadow: 0px 0px 34px 0px rgba(0,0,0,0.08);
  border-radius: 2.4rem;
  opacity: 0;
  -webkit-transform: translateY(1.3rem);
  transform: translateY(1.3rem);
  -webkit-transition: all 0.3s ease 0.3s;
  transition: all 0.3s ease 0.3s;
}

.modal-img .modal-inner-box {
  width: 100%;
  max-width: 100%;
  margin-top: 3.4rem;
  background-color: transparent;
  -webkit-box-shadow: 0px 0px 21px 0px rgba(23,50,77,0);
  box-shadow: 0px 0px 21px 0px rgba(23,50,77,0);
  border-radius: 0;
}

.show-modal-search .modal-inner-box,
.show-modal-img .modal-inner-box {
  opacity: 1;
  -webkit-transform: translateY(0);
  transform: translateY(0);
}

.modal-inner-box .close {
  position: absolute;
  z-index: 9999;
  cursor: pointer;
  top: 0.8rem;
  right: 0.8rem;
  width: 2.9rem;
  height: auto;
}

.modal-img .modal-inner-box .close {
  top: -1.3rem;
  right: 0.8rem;
}

.modal-inner-content {
  padding: 2.1rem;
}

.modal-img .modal-inner-content {
  padding: 3.4rem;
  padding-top: 2.1rem;
}

.modal-img .modal-inner-content img {
  -webkit-box-shadow: 0px 0px 34px 0px rgba(23,50,77,0.1);
  box-shadow: 0px 0px 34px 0px rgba(23,50,77,0.1);
}

.modal-img .modal-inner-content img[alt="diagram"],
.modal-img .modal-inner-content img.uml {
  -webkit-box-shadow: 0px 0px 34px 0px rgba(23,50,77,0);
  box-shadow: 0px 0px 34px 0px rgba(23,50,77,0);
}

.modal-search button {
  display: block;
  width: 100%;
}

/* INTERNAL NAV */

.internal-nav {
  background-color: var(--dark);
}

.internal-nav-links {
  display: -webkit-box;      /* OLD - iOS 6-, Safari 3.1-6 */
  display: -moz-box;         /* OLD - Firefox 19- (buggy but mostly works) */
  display: -ms-flexbox;      /* TWEENER - IE 10 */
  display: -webkit-flex;     /* NEW - Chrome */
  display: flex;
  -webkit-align-items: center;
  -ms-align-items: center;
  align-items: center;
  -webkit-align-content: center;
  -ms-align-content: center;
  align-content: center;
}

.internal-nav-link-previous {
  width: 30%;
}

.internal-nav-link-next {
  width: 70%;
}

@media (min-width: 1000px) {
  .internal-nav-link-previous,
  .internal-nav-link-next {
    width: 50%;
  }
}

.internal-nav-next,
.internal-nav-previous {
  display: -webkit-box;      /* OLD - iOS 6-, Safari 3.1-6 */
  display: -moz-box;         /* OLD - Firefox 19- (buggy but mostly works) */
  display: -ms-flexbox;      /* TWEENER - IE 10 */
  display: -webkit-flex;     /* NEW - Chrome */
  display: flex;
  -webkit-align-items: center;
  -ms-align-items: center;
  align-items: center;
  -webkit-align-content: center;
  -ms-align-content: center;
  align-content: center;
}

.internal-nav-previous {
  -webkit-justify-content: flex-start;
  -ms-justify-content: flex-start;
  justify-content: flex-start;
  text-align: left;
}

.internal-nav-next {
  -webkit-justify-content: flex-end;
  -ms-justify-content: flex-end;
  justify-content: flex-end;
  text-align: right;
}

.internal-nav .arrow {
  width: 3.9rem;
  flex-shrink: 0;
  -webkit-transition: all 0.3s ease;
  transition: all 0.3s ease;
}

.internal-nav .arrow-left {
  margin-right: 0.8rem;
}

.internal-nav-link:hover .arrow-left {
  -webkit-transform: translateX(-0.8rem);
  transform: translateX(-0.8rem);
}

.internal-nav .arrow-right {
  margin-left: 0.8rem;
}

.internal-nav-link:hover .arrow-right {
  -webkit-transform: translateX(0.8rem);
  transform: translateX(0.8rem);
}

.internal-nav-link a {
  color: var(--white);
  text-decoration: none;
  display: block;
  padding-top: 5vh;
  padding-bottom: 5vh;
}

.internal-nav-link h6 {
  font-size: 1.3rem;
  text-transform: uppercase;
  letter-spacing: 0.1rem;
  margin-bottom: 0.3rem;
  opacity: 0.5;
  -webkit-transition: all 0.3s ease;
  transition: all 0.3s ease;
}

.internal-nav-link:hover h6 {
  opacity: 0.6;
}

.internal-nav-link h5 {
  font-size: 2.1rem;
  margin-bottom: 0.3rem;
  opacity: 0.8;
  -webkit-transition: all 0.3s ease;
  transition: all 0.3s ease;
}

.internal-nav-link:hover h5 {
  opacity: 1;
}

.internal-nav-link-previous-label {
  display: none;
}

@media (min-width: 1000px) {
  .internal-nav-link-previous-label {
    display: block;
    flex-shrink: 1;
  }
}
